@@ -8,12 +8,14 @@ from abc import abstractmethod
 from datetime import date, datetime, timedelta
 from operator import attrgetter
 from typing import (Any, Callable, Dict, Iterable, List, Mapping, Optional,
-                    Sequence, Set, Type, TypeVar, Union, no_type_check,
+                    Sequence, Set, Tuple, Type, TypeVar, Union, no_type_check,
                     overload)
 from urllib.parse import unquote
 
 import gremlin_python
 from amundsen_common.models.dashboard import DashboardSummary
+from amundsen_common.models.feature import Feature
+from amundsen_common.models.generation_code import GenerationCode
 from amundsen_common.models.lineage import Lineage
 from amundsen_common.models.popular_table import PopularTable
 from amundsen_common.models.table import (Application, Column,
@@ -1010,6 +1012,9 @@ class AbstractGremlinProxy(BaseProxy):
         user.manager_fullname = _safe_get(managers[0], 'full_name', default=None) if managers else None
         return user
 
+    def create_update_user(self, *, user: User) -> Tuple[User, bool]:
+        pass
+
     @timer_with_counter
     @overrides
     def get_users(self) -> List[User]:
@@ -1230,7 +1235,7 @@ class AbstractGremlinProxy(BaseProxy):
 
         g = _V(g=self.g, label=VertexTypes.Table, key=table_uri). \
             outE(EdgeTypes.Description.value.label).inV(). \
-            has(VertexTypes.Description.value.label, 'source', 'user'). \
+            has('description_source', 'description'). \
             values('description').fold()
         descriptions = self.query_executor()(query=g, get=FromResultSet.getOnly)
         return _safe_get(descriptions)
@@ -1250,9 +1255,10 @@ class AbstractGremlinProxy(BaseProxy):
         description = unquote(description)
 
         # default table description is user added
-        desc_key = make_description_uri(subject_uri=table_uri, source='user')
+        desc_key = make_description_uri(subject_uri=table_uri, source='description')
+
         _upsert(executor=executor, g=self.g, label=VertexTypes.Description, key=desc_key,
-                key_property_name=self.key_property_name, description=description, source='user')
+                key_property_name=self.key_property_name, description=description, description_source='description')
         _link(executor=executor, g=self.g, edge_label=EdgeTypes.Description, key_property_name=self.key_property_name,
               vertex1_label=VertexTypes.Table, vertex1_key=table_uri,
               vertex2_label=VertexTypes.Description, vertex2_key=desc_key)
@@ -1352,9 +1358,12 @@ class AbstractGremlinProxy(BaseProxy):
 
         column_uri = make_column_uri(table_uri=table_uri, column_name=column_name)
         # default table description is user added
-        desc_key = make_description_uri(subject_uri=column_uri, source='user')
-        vertex_id: Any = _upsert(executor=executor, g=self.g, label=VertexTypes.Description, key=desc_key,
-                                 key_property_name=self.key_property_name, description=description, source='user')
+        desc_key = make_description_uri(subject_uri=column_uri, source='description')
+        vertex_id: Any = _upsert(
+            executor=executor, g=self.g,
+            label=VertexTypes.Description, key=desc_key, key_property_name=self.key_property_name,
+            description=description, description_source='description'
+        )
         _link(executor=executor, g=self.g, edge_label=EdgeTypes.Description, key_property_name=self.key_property_name,
               vertex1_label=VertexTypes.Column, vertex1_key=column_uri, vertex2_id=vertex_id)
 
@@ -1371,7 +1380,7 @@ class AbstractGremlinProxy(BaseProxy):
         column_uri = make_column_uri(table_uri=table_uri, column_name=column_name)
         g = _V(g=self.g, label=VertexTypes.Column, key=column_uri)
         g = g.outE(EdgeTypes.Description.value.label).inV()
-        g = g.has(VertexTypes.Description.value.label, 'source', 'user').values('description')
+        g = g.has(VertexTypes.Description.value.label, 'description_source', 'description').values('description')
         return self.query_executor()(query=g, get=FromResultSet.getOptional)
 
     @timer_with_counter
@@ -1455,6 +1464,10 @@ class AbstractGremlinProxy(BaseProxy):
                      key=AMUNDSEN_TIMESTAMP_KEY).values('latest_timestamp').toList()
         return _safe_get(results, transform=int)
 
+    def get_statistics(self) -> Dict[str, Any]:
+        # Not implemented
+        pass
+
     @timer_with_counter
     @overrides
     def get_tags(self) -> List:
@@ -1730,6 +1743,37 @@ class AbstractGremlinProxy(BaseProxy):
                     id: str, resource_type: ResourceType, direction: str, depth: int) -> Lineage:
         pass
 
+    def get_feature(self, *, feature_uri: str) -> Feature:
+        pass
+
+    def get_resource_description(self, *,
+                                 resource_type: ResourceType,
+                                 uri: str) -> Description:
+        pass
+
+    def put_resource_description(self, *,
+                                 resource_type: ResourceType,
+                                 uri: str,
+                                 description: str) -> None:
+        pass
+
+    def add_resource_owner(self, *,
+                           uri: str,
+                           resource_type: ResourceType,
+                           owner: str) -> None:
+        pass
+
+    def delete_resource_owner(self, *,
+                              uri: str,
+                              resource_type: ResourceType,
+                              owner: str) -> None:
+        pass
+
+    def get_resource_generation_code(self, *,
+                                     uri: str,
+                                     resource_type: ResourceType) -> GenerationCode:
+        pass
+
 
 class GenericGremlinProxy(AbstractGremlinProxy):
     """
